@@ -12,11 +12,14 @@ def run(config, args):
     channel.tx_select()
     failed_queue = Queue('kuyruk_failed', channel)
 
+    count = 0
     while 1:
         tag, task_description = failed_queue.receive()
         if task_description is None:
             break
 
+        print "Requeueing task: %r" % task_description
+
         queue_name = task_description['queue']
         del task_description['queue']
         task_queue = Queue(queue_name, channel)
@@ -24,5 +27,6 @@ def run(config, args):
 
         failed_queue.ack(tag)
         channel.tx_commit()
+        count += 1
 
-    logger.info('All failed task are requeued.')
+    print "%i failed tasks are requeued." % count
